# GatewayRequest

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**cluster_name** | **str** |  | 
**provider_config** | [**object**](.md) |  | 
**type** | **str** |  | 
**request_id** | **str** |  | 
**args** | **object** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


